@@ -2,6 +2,9 @@ use crate::crossdev;
 use crate::traverse::{EntryData, Tree, TreeIndex};
 use byte_unit::{n_gb_bytes, n_gib_bytes, n_mb_bytes, n_mib_bytes, ByteUnit};
 use std::path::PathBuf;
+use std::sync::atomic::{AtomicBool, Ordering};
+use std::sync::Arc;
+use std::time::Duration;
 use std::{fmt, path::Path};
 
 pub fn get_entry_or_panic(tree: &Tree, node_idx: TreeIndex) -> &EntryData {
@@ -114,6 +117,47 @@ pub enum TraversalSorting {
     AlphabeticalByFileName,
 }
 
+/// Throttle access to an optional `io::Write` to the specified `Duration`
+#[derive(Debug)]
+pub struct Throttle {
+    trigger: Arc<AtomicBool>,
+}
+
+impl Throttle {
+    pub fn new(duration: Duration, initial_sleep: Option<Duration>) -> Self {
+        let instance = Self {
+            trigger: Default::default(),
+        };
+
+        let trigger = Arc::downgrade(&instance.trigger);
+        std::thread::spawn(move || {
+            if let Some(duration) = initial_sleep {
+                std::thread::sleep(duration)
+            }
+            while let Some(t) = trigger.upgrade() {
+                t.store(true, Ordering::Relaxed);
+                std::thread::sleep(duration);
+            }
+        });
+
+        instance
+    }
+
+    pub fn throttled<F>(&self, f: F)
+    where
+        F: FnOnce(),
+    {
+        if self.can_update() {
+            f()
+        }
+    }
+
+    /// Return `true` if we are not currently throttled.
+    pub fn can_update(&self) -> bool {
+        self.trigger.swap(false, Ordering::Relaxed)
+    }
+}
+
 /// Configures a filesystem walk, including output and formatting options.
 #[derive(Clone)]
 pub struct WalkOptions {
