@@ -102,7 +102,11 @@ impl HelpPane {
                     "Close the current pane. Closes the program if no",
                     Some("pane is open"),
                 );
-                hotkey("<Tab>", "Cycle between all open panes", None);
+                hotkey(
+                    "<Tab>",
+                    "Cycle between all open panes.",
+                    Some("Activate 'Marked Items' pane to delete selected files."),
+                );
                 hotkey("?", "Show or hide the help pane", None);
                 spacer();
             }
@@ -150,7 +154,7 @@ impl HelpPane {
                 );
                 hotkey(
                     "x",
-                    "Mark for the currently selected entry for deletion and move down",
+                    "Mark the currently selected entry for deletion and move down",
                     None,
                 );
                 hotkey("<Space>", "Toggle the currently selected entry", None);
